@@ -86,5 +86,4 @@ def Fishconsole_project():
     from Fishconsole import fcv
     fcv.f_debug()
 
-import os
-os.startfile("C:/Users/lenovo/PycharmProjects/xiaoxiao2/main.py")
+
