@@ -80,11 +80,10 @@ except KeyboardInterrupt:
 r'''
 
 
-    
 import os
 from Fishconsole import logs
-pid=os.getpid()
-print(logs.日志(f'Fishconsole 随机ip代理池启动{pid}','绿色'))
+pid =os.getpid()
+print(logs.日志(f'Fishconsole 随机ip代理池启动{pid}' ,'绿色'))
 
 try:
     def 爬虫进程():
@@ -96,11 +95,41 @@ try:
             import time
 
             print(logs.日志('爬虫进程启动', 色选='青色'))
+
+            原始代理池 = []
+            计数器 = 0
+
             while True:
                 try:
-                    print(logs.日志("spaider 25%"))
+                    if 计数器 == 7:
+                        break
+
+
+                    res = requests.get(f'https://free.kuaidaili.com/free/inha/{str(计数器)}').text
+
+                    res = etree.HTML(res)
+
+                    原始ip = res.xpath('//tbody/tr/td[1]/text()')
+
+                    原始端口 = res.xpath('//tbody/tr/td[2]/text()')
+                    初始化代理池 = list(zip(原始ip, 原始端口))
+                    for a, b in 初始化代理池:
+                        c = a + ':' + b
+                        原始代理池.append(c)
+                        print(logs.日志(f"1号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
+                    计数器 = 计数器 + 1
+                except:
+                    print(logs.日志("爬虫进程报错，十秒后重启"))
+                    time.sleep(10)
+
+
+
+
+            while True:
+                try:
+
                     链接 = "https://uu-proxy.com/api/free"
-                    原始代理池 = []
+
                     res = requests.get(链接).text
                     原始ip = re.findall('"ip":"(.*?)",', res)
                     原始端口 = re.findall('"port":(.*?),', res)
@@ -109,15 +138,16 @@ try:
                     for a, b in 初始化代理池:
                         c = a + ':' + b
                         原始代理池.append(c)
+                        print(logs.日志(f"2号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
                 except:
                     print(logs.日志("爬虫进程报错，十秒后重启"))
                     time.sleep(10)
                 try:
                     计数器 = 0
                     while True:
-                        if 计数器 == 1:
+                        if 计数器 == 3:
                             break
-                        print(logs.日志("spaider 50%"))
+
                         res = requests.get(f'https://ip.jiangxianli.com/?page={计数器}').text
                         res = etree.HTML(res)
 
@@ -129,6 +159,7 @@ try:
                         for a, b in 初始化代理池:
                             c = a + ':' + b
                             原始代理池.append(c)
+                            print(logs.日志(f"3号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
 
                         计数器 = 计数器 + 1
                 except:
@@ -137,7 +168,7 @@ try:
                 计数器 = 0
                 try:
                     while True:
-                        print(logs.日志("spaider 75%"))
+
                         res = etree.HTML(requests.get(f'http://www.ip3366.net/?page={计数器}').text)
                         原始ip = res.xpath('//*[@id="list"]/table/tbody/tr/td[1]/text()')
                         原始端口 = res.xpath('//*[@id="list"]/table/tbody/tr/td[2]/text()')
@@ -146,7 +177,8 @@ try:
                         for a, b in 初始化代理池:
                             c = a + ':' + b
                             原始代理池.append(c)
-                        if 计数器 == 1:
+                            print(logs.日志(f"4号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
+                        if 计数器 == 5:
                             break
 
                         计数器 = 计数器 + 1
@@ -168,9 +200,9 @@ try:
                 原始端口_清洗存储 = []
                 try:
                     while True:
-                        if 计数器 == 1:
+                        if 计数器 == 5:
                             break
-                        print(logs.日志("spaider 100%"))
+
                         res = etree.HTML(requests.get(f'https://www.89ip.cn/index_{计数器}.html').text)
                         原始ip = res.xpath('//tbody/tr/td[1]/text()')
                         原始端口 = res.xpath('//tbody/tr/td[2]/text()')
@@ -189,23 +221,27 @@ try:
 
                         for a, b in 初始化代理池:
                             c = a + ':' + b
+                            print(logs.日志(f"5号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个", 色选='青色'))
+
                             原始代理池.append(c)
 
                         计数器 = 计数器 + 1
 
                     from Fishconsole import Fishsys
-                    原始代理池 = Fishsys.list去重(原始代理池)
+                    print(原始代理池)
                 except:
                     print(logs.日志("爬虫进程报错，十秒后重启"))
                     time.sleep(10)
 
+                去重代理池 = Fishsys.list去重(原始代理池)
                 if not files.文件存在性检测('C:\Fishconsole\programes\Tempfiles\ipCore.fcc'):
-                    files.缓存(1, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 原始代理池})
+                    files.缓存(1, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 去重代理池})
                 else:
-                    files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 原始代理池})
-
-                print(logs.日志('爬虫进程睡眠六十秒钟', 色选='青色'))
-                time.sleep(60)
+                    files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 去重代理池})
+                print(len(原始代理池))
+                print(len(去重代理池))
+                print(logs.日志(f'爬虫进程睡眠1000秒钟，本次去重{len(原始代理池)-len(去重代理池)}条项目，剩下{len(去重代理池)}', 色选='青色'))
+                time.sleep(1000)
         except KeyboardInterrupt:
             from Fishconsole import logs
             print(logs.日志('Fishconsole ipmadom(爬虫进程) 已安全退出', '蓝色'))
@@ -226,6 +262,7 @@ try:
             线程池 = []
 
             def 解析器(数据源):
+
                 try:
                     for a in 数据源:
                         # print(logs.日志(f"验证代理{a}","蓝色"))
@@ -235,6 +272,7 @@ try:
                                 'https://www.kuaidaili.com/dps/?utm_source=ggtg&utm_campaign=D5b0&utm_medium=D4&gclid=EAIaIQobChMI9Oziy_Tv-AIVescWBR1MrgGkEAEYASAAEgKPhvD_BwE',
                                 proxies=proxies, timeout=15).text
                             可用代理.append(a)
+
                         except:
                             pass
 
@@ -246,31 +284,48 @@ try:
                 if 原始代理 == False:
                     原始代理 = []
                 验证代理 = files.缓存(模式=2, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 变量名='Available')
+
+
                 if 验证代理 == False:
                     验证代理 = []
                 if 验证代理 == 'error':
                     验证代理 = []
-                数据源 = 原始代理 + 验证代理
                 try:
-                    for a in Fishsys.任务平均分配(30, 数据源):
+                    数据源 = 原始代理 + 验证代理
+                except TypeError:
+                    数据源=[]
+
+
+                try:
+                    for a in Fishsys.任务平均分配(29, 数据源):
                         线程池.append(threading.Thread(target=解析器, kwargs={'数据源': a}))
                         线程池[-1].start()
                     for 守护 in 线程池:
                         守护.join()
                 except:
-                    time.sleep(10)
-                    continue
-                files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'Available': Fishsys.list去重(可用代理)})
+                    files.缓存(模式=3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'Available': []})
+
+
+
+
+
                 print(logs.日志(f'验证进程已完成{len(数据源)}条代理的验证,可用代理有{len(Fishsys.list去重(可用代理))}个', 色选='蓝色'))
+
+                files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'Available': Fishsys.list去重(可用代理)})
+
+                可用代理 = []
+
+                del 数据源
                 print(logs.日志('验证进程睡眠二十秒钟', 色选='蓝色'))
-                time.sleep(10)
+
+                time.sleep(20)
         except KeyboardInterrupt:
             from Fishconsole import logs
             print(logs.日志('Fishconsole ipmadom(验证进程) 已安全退出', '蓝色'))
 
 
     if __name__ == '__main__':
-        from Fishconsole import logs,files,Fishsys
+        from Fishconsole import logs ,files ,Fishsys
         import multiprocessing
         import time
 
@@ -299,7 +354,7 @@ except KeyboardInterrupt:
     print(logs.日志('Fishconsole ipmadom 已安全退出', '蓝色'))
 
 
-     
+
 
  '''
 
